<?php
/**
 * Galicianlanguage file
 *
 * @author CiberIrmandade da Fala <infoxeral@ciberirmandade.org>
 */
$lang['menu']                  = 'Xestionar Plugins';
$lang['download']              = 'Descargar e instalar un novo plugin';
$lang['manage']                = 'Plugins Instalados';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'actualización';
$lang['btn_delete']            = 'eliminar';
$lang['btn_settings']          = 'configuración';
$lang['btn_download']          = 'Descargar';
$lang['btn_enable']            = 'Gardar';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalado:';
$lang['lastupdate']            = 'Última actualización:';
$lang['source']                = 'Fonte:';
$lang['unknown']               = 'descoñecido';
$lang['updating']              = 'Actualizando...';
$lang['updated']               = 'Actualizouse correctamente o plugin %s';
$lang['updates']               = 'Actualizáronse correctamente os seguintes plugins';
$lang['update_none']           = 'Non se atoparon actualizacións.';
$lang['deleting']              = 'Eliminando...';
$lang['deleted']               = 'Eliminado o plugin %s.';
$lang['downloading']           = 'Descargando...';
$lang['downloaded']            = 'Instalouse correctamente o plugin %s';
$lang['downloads']             = 'Instaláronse correctamente os seguintes plugins:';
$lang['download_none']         = 'Non se atoparon plugins, ou aconteceu un problema descoñecido durante a descarga e instalación.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Compoñentes';
$lang['noinfo']                = 'Este plugin non devolveu información ningunha, pode que non sexa válido.';
$lang['name']                  = 'Nome:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Descrición:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Houbo un erro descoñecido.';
$lang['error_download']        = 'Non se puido descargar o arquivo de plugin: %s';
$lang['error_badurl']          = 'URL posiblemente incorrecto - non se puido determinar o nome do arquivo mediante o URL';
$lang['error_dircreate']       = 'Non se puido crear un cartafol temporal para recibir a descarga';
$lang['error_decompress']      = 'O xestor de plugins non foi quen de descomprimir o arquivo descargado. Isto podería ser causado por unha descarga corrupta, polo que, en tal caso, podes tentalo de novo; ou pode que o formato de compresión sexa descoñecido, co que precisarás descargar e instalar o plugin de xeito manual.';
$lang['error_copy']            = 'Houbo un erro de copia de arquivo ao tentar instalar o plugin <em>%s</em>: pode que o disco estea cheo ou que os permisos de acceso sexan incorrectos. Isto podería dar lugar a unha instalación parcial do plugin e facer que a túa instalación do wiki se volva inestable.';
$lang['error_delete']          = 'Houbo un erro ao tentar eliminar o plugin <em>%s</em>. O máis probable é que sexa causado por permisos de acceso ao arquivo ou directorio insuficientes.';
$lang['enabled']               = 'Complemento %s activado.';
$lang['notenabled']            = 'O complemento %s non puido ser activado, comproba os permisos de arquivo.';
$lang['disabled']              = 'Complemento %s desactivado.';
$lang['notdisabled']           = 'O complemento %s non puido ser desactivado, comproba os permisos de arquivo.';
